==> QupZilla-2.2.0.tar.xz: QupZilla-2.2.0/src/plugins/FlashCookieManager/translations/sl_SI.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl_SI" version="2.1">
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>Flash piškotki</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>Shranjeni Flash piškotki</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>Najdi: </translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <location filename="../fcm_dialog.cpp" line="153"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;flash piškotek ni izbran&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>Zadnja sprememba:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <source>Origin:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>Naloži z diska</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>Pot:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>Kliknite, da odprete vsebujočo mapo</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>Odstrani vse flash piškotke</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="156"/>
        <source>Remove flash cookies</source>
        <translation>Odstrani flash piškotke</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>Filtriranje flash piškotkov</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Beli seznam flash piškotkov&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation>Flash piškotki iz teh naslovov ne bodo izbrisani samodejno. (Prav tako o njih uporabnik ne bo obveščen)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Črni seznam flash piškotkov&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation>Flash piškotki is teh naslovov bodo izbrisani brez obvestila.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavitve Flash piškotkov&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation>Samodejni način: Mapa s podatki flash bo redno preverjana. in flash piškotki v črnem seznamu bodo samodejno izbrisani.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>Izbriši vse flash piškotke ob izhodu/zagonu. (razen tistih na belem seznamu)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="76"/>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="93"/>
        <source>Confirmation</source>
        <translation>Potrditev</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="94"/>
        <source>Are you sure you want to delete all flash cookies on your computer?</source>
        <translation>Ali ste prepričani, da želite izbrisati vse flash piškotke na vašem računalniku?</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="166"/>
        <location filename="../fcm_dialog.cpp" line="237"/>
        <source> (settings)</source>
        <translation>(nastavitve)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="169"/>
        <source> Byte</source>
        <translation>Bajt</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="175"/>
        <source>Remove flash cookie</source>
        <translation>Odstrani flash piškotek</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="241"/>
        <source> [new]</source>
        <translation>[nov]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="375"/>
        <source>Add to whitelist</source>
        <translation>Dodaj na beli seznam</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>Already whitelisted!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <source>The server &quot;%1&quot; is already in blacklist, please remove it first.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <location filename="../fcm_dialog.cpp" line="374"/>
        <source>Add to blacklist</source>
        <translation>Dodaj na črni seznam</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>The origin &quot;%1&quot; is already in whitelist, please remove it first.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>Zaznan nov flash piškotek!</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>Poglej</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>Zaznan je nov flash piškotek</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>Zaznanih je %1 novih flash piškotkov</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="129"/>
        <source>Flash Cookie Manager</source>
        <translation>Upravljalnik flash piškotkov</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="357"/>
        <source>Show Flash Cookie Manager</source>
        <translation>Pokaži upravljalnik flash piškotkov</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="439"/>
        <source>!default</source>
        <translation>!privzeto</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="451"/>
        <source>!other</source>
        <translation>!ostalo</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.3.tar.xz: QupZilla-2.2.3/src/plugins/FlashCookieManager/translations/sl_SI.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl_SI" version="2.1">
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>Flash piškotki</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>Shranjeni Flash piškotki</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>Najdi: </translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <location filename="../fcm_dialog.cpp" line="153"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;flash piškotek ni izbran&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>Zadnja sprememba:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <source>Origin:</source>
        <translation>Izvor:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation>Izvlečeni nizi latin1:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation>Ti flash piškotki so shranjeni na vašem računalniku:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation>Izvor</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>Naloži z diska</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>Pot:</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>Kliknite, da odprete vsebujočo mapo</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>Odstrani vse flash piškotke</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="156"/>
        <source>Remove flash cookies</source>
        <translation>Odstrani flash piškotke</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>Filtriranje flash piškotkov</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Beli seznam flash piškotkov&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation>Flash piškotki iz teh naslovov ne bodo izbrisani samodejno. (Prav tako o njih uporabnik ne bo obveščen)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Črni seznam flash piškotkov&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation>Flash piškotki is teh naslovov bodo izbrisani brez obvestila.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nastavitve Flash piškotkov&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation>Samodejni način: Mapa s podatki flash bo redno preverjana. in flash piškotki v črnem seznamu bodo samodejno izbrisani.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opomba:&lt;/span&gt; Te nastavitve se uveljavljajo samo na flash piškotkih. Za upravljanje HTTP piškotkov uporabite &lt;span style=&quot; font-weight:600;&quot;&gt;Upravljalnik Piškotkov&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation>Obvestilo: Uporabnik bo obveščen o vsakem novem flash piškotku, ki ni na črnem ali belem seznamu.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>Izbriši vse flash piškotke ob izhodu/zagonu. (razen tistih na belem seznamu)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="76"/>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="93"/>
        <source>Confirmation</source>
        <translation>Potrditev</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="94"/>
        <source>Are you sure you want to delete all flash cookies on your computer?</source>
        <translation>Ali ste prepričani, da želite izbrisati vse flash piškotke na vašem računalniku?</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="166"/>
        <location filename="../fcm_dialog.cpp" line="237"/>
        <source> (settings)</source>
        <translation>(nastavitve)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="169"/>
        <source> Byte</source>
        <translation>Bajt</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="175"/>
        <source>Remove flash cookie</source>
        <translation>Odstrani flash piškotek</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="241"/>
        <source> [new]</source>
        <translation>[nov]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="375"/>
        <source>Add to whitelist</source>
        <translation>Dodaj na beli seznam</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>Already whitelisted!</source>
        <translation>Že na belem seznamu!</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <source>The server &quot;%1&quot; is already in blacklist, please remove it first.</source>
        <translation>Strežnik &quot;%1&quot; je že na belem seznamu, najprej ga odstranite.</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <location filename="../fcm_dialog.cpp" line="374"/>
        <source>Add to blacklist</source>
        <translation>Dodaj na črni seznam</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>The origin &quot;%1&quot; is already in whitelist, please remove it first.</source>
        <translation>Strežnik &quot;%1&quot; je že na črnem seznamu, najprej ga odstranite.</translation>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>Zaznan nov flash piškotek!</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>Poglej</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>Zaznan je nov flash piškotek</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>Zaznanih je %1 novih flash piškotkov</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="129"/>
        <source>Flash Cookie Manager</source>
        <translation>Upravljalnik flash piškotkov</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="357"/>
        <source>Show Flash Cookie Manager</source>
        <translation>Pokaži upravljalnik flash piškotkov</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="439"/>
        <source>!default</source>
        <translation>!privzeto</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="451"/>
        <source>!other</source>
        <translation>!ostalo</translation>
    </message>
</context>
</TS>
